aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--if.c2
-rw-r--r--if.h2
-rw-r--r--ip_icmp.c6
-rw-r--r--ip_output.c6
-rw-r--r--slirp.h2
-rw-r--r--tcp_subr.c2
6 files changed, 10 insertions, 10 deletions
diff --git a/if.c b/if.c
index c939029..9ddb20b 100644
--- a/if.c
+++ b/if.c
@@ -8,8 +8,6 @@
#include <slirp.h>
int if_queued = 0; /* Number of packets queued so far */
-int if_thresh = 10; /* Number of packets queued before we start sending
- * (to prevent allocing too many mbufs) */
struct mbuf if_fastq; /* fast queue (for interactive data) */
struct mbuf if_batchq; /* queue for non-interactive data */
diff --git a/if.h b/if.h
index 21d3f76..2b1306f 100644
--- a/if.h
+++ b/if.h
@@ -33,8 +33,6 @@
#endif
extern int if_queued; /* Number of packets queued so far */
-extern int if_thresh; /* Number of packets queued before we start sending
- * (to prevent allocing too many mbufs) */
extern struct mbuf if_fastq; /* fast queue (for interactive data) */
extern struct mbuf if_batchq; /* queue for non-interactive data */
diff --git a/ip_output.c b/ip_output.c
index a014249..8cd0e93 100644
--- a/ip_output.c
+++ b/ip_output.c
@@ -46,6 +46,10 @@
u_int16_t ip_id;
+/* Number of packets queued before we start sending
+ * (to prevent allocing too many mbufs) */
+#define IF_THRESH 10
+
/*
* IP output. The packet in mbuf chain m contains a skeletal IP
* header (with len, off, ttl, proto, tos, src, dst).
@@ -85,7 +89,7 @@ struct mbuf *m0;
* the packet or packet fragments
*/
/* XXX Hmmm... */
- /* if (if_queued > if_thresh && towrite <= 0) {
+ /* if (if_queued > IF_THRESH && towrite <= 0) {
* error = ENOBUFS;
* goto bad;
* }
diff --git a/slirp.h b/slirp.h
index 2a5a629..d647564 100644
--- a/slirp.h
+++ b/slirp.h
@@ -266,8 +266,6 @@ long gethostid _P((void));
void lprint _P((const char *, ...));
-extern int do_echo;
-
#if SIZEOF_CHAR_P == 4
#define insque_32 insque
#define remque_32 remque
diff --git a/tcp_subr.c b/tcp_subr.c
index d535d8d..c3c3541 100644
--- a/tcp_subr.c
+++ b/tcp_subr.c
@@ -579,7 +579,9 @@ u_int8_t tcp_tos(so) struct socket *so;
return 0;
}
+#if 0
int do_echo = -1;
+#endif
/*
* Emulate programs that try and connect to us
diff --git a/ip_icmp.c b/ip_icmp.c
index 5e7956a..bf7c855 100644
--- a/ip_icmp.c
+++ b/ip_icmp.c
@@ -42,9 +42,9 @@ struct icmpstat icmpstat;
#endif
/* The message sent when emulating PING */
-/* Be nice and tell them it's just a psuedo-ping packet */
-char icmp_ping_msg[] = "This is a psuedo-PING packet used by Slirp to emulate "
- "ICMP ECHO-REQUEST packets.\n";
+/* Be nice and tell them it's just a pseudo-ping packet */
+const char icmp_ping_msg[] = "This is a pseudo-PING packet used by Slirp to "
+ "emulate ICMP ECHO-REQUEST packets.\n";
/* list of actions for icmp_error() on RX of an icmp message */
static const int icmp_flush[19] = {